@@ -76,6 +76,7 @@ if BD_USE_SIMPLEUI and BD_USE_AJAX_ADMIN:
 
     IAdmin = AjaxAdmin
 
+
 if BD_USE_GUARDIAN:
     from guardian.admin import GuardedModelAdminMixin
 
@@ -226,6 +227,24 @@ class BulkDeleteMixin:
     bulk_delete.confirm = "确定要批量删除选中的数据么?"
 
 
+class BulkUpdateMixin:
+    """
+    批量更新
+    """
+
+    @admin.action(permissions=['change'])
+    def bulk_update(self, request, queryset=None, model=None):
+        t_update = Time()
+        count = queryset.count()
+        for qs_i in queryset:
+            qs_i.save()
+        self.message_user(request, f"成功更新{count}条数据, 耗时: {t_update.now(1)}秒.")
+
+    bulk_update.short_description = "批量更新"
+    bulk_update.icon = 'fa fa-spinner'
+    bulk_update.confirm = "确定要批量更新选中的数据么?"
+
+
 class ExportExcelMixin:
     export_ordering = None      # 导出时的排序
     export_fields = None        # 需要导出的字段
