@@ -10,7 +10,9 @@ from django.contrib.contenttypes.models import ContentType
 from bddjango import convert_query_parameter_to_bool, my_api_assert_function
 from bddjango import find_indexes_in_dc_ls
 from bddjango import get_base_model
+from bddjango import get_field_names_by_model
 
+import sys
 
 tmp_urls = None
 tmp_views = None
@@ -88,9 +90,8 @@ def set_options(ls):
         }
         options.append(dc)
     ContentTypeAdmin.auto_wiki.layer['params'][0]['options'] = options
-
-
-from bddjango import get_field_names_by_model
+    if len(options) == 1:
+        ContentTypeAdmin.auto_wiki.layer['params'][0]['value'] = options[0].get('key')
 
 
 class ContentTypeAdmin(BaseAdmin):
@@ -176,7 +177,11 @@ class ContentTypeAdmin(BaseAdmin):
         _view_class = post.get('view_class')
 
         if _view_class:
-            app_label, view_class = _view_class.split('.')
+            try:
+                app_label, view_class = _view_class.split('.')
+            except Exception as e:
+                print("Error _view_class: ", _view_class)
+                raise e
 
             from bddjango.autoWiki import AutoWiki
             from django.test.client import ASGIRequest, FakePayload
@@ -219,13 +224,16 @@ class ContentTypeAdmin(BaseAdmin):
 
             output_filename = f'wiki__{_view_class}.txt'
             output_filepath = os.path.join(output_dirpath, output_filename)
-            with open(output_filepath, 'w', encoding='utf-8') as f:
+            output_encoding = 'gbk' if sys.platform == 'win32' else 'utf-8'
+
+            with open(output_filepath, 'w', encoding=output_encoding) as f:
                 f.write(content)
 
             print('---------- autoWiki:')
             print(content)
 
-            msg = f'成功生成wiki, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_filepath}" target="_blank">点击此处查看</a>'
+            # msg = f'成功生成wiki, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_filepath}" target="_blank">点击此处查看</a>'
+            msg = f'成功生成wiki, 耗时: {tt.now(2)}秒. <br> <a href="/api/file_upload/Doc/?output_filepath={output_filepath}" target="_blank">点击此处查看</a>'
             self.message_user(request, msg)
 
             from bddjango import remove_temp_file
@@ -317,7 +325,6 @@ class ContentTypeAdmin(BaseAdmin):
         my_api_assert_function(os.path.exists(codes_template_file_path),
                                f'`codes_template_file_path`路径不存在![{codes_template_file_path}]')
 
-
         # region # --- 开始填充jinja模板
         from jinja2 import Template
 
@@ -339,7 +346,9 @@ class ContentTypeAdmin(BaseAdmin):
         if os.path.exists(output_fpath):
             os.remove(output_fpath)
 
-        _fields = get_field_names_by_model(md_i, exclude_fields=['id'])
+        _fields = get_field_names_by_model(md_i)
+        if len(_fields) > 2:
+            _fields.remove('id')
 
         field_dc_ls = []
         field_dc_i = {}
@@ -387,13 +396,15 @@ class ContentTypeAdmin(BaseAdmin):
 
         content = template.render(**res_context_dc)
 
-        with open(output_fpath, 'w', encoding='utf-8') as f:
+        output_encoding = 'gbk' if sys.platform == 'win32' else 'utf-8'
+        with open(output_fpath, 'w', encoding=output_encoding) as f:
             f.write(content)
 
         print('\n---------- autoCodes:')
         print(content)
 
-        msg = f'成功生成代码, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_fpath}" target="_blank">点击此处查看</a>'
+        # msg = f'成功生成代码, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_fpath}" target="_blank">点击此处查看</a>'
+        msg = f'成功生成wiki, 耗时: {tt.now(2)}秒. <br> <a href="/api/file_upload/Doc/?output_filepath={output_fpath}" target="_blank">点击此处查看</a>'
         self.message_user(request, msg)
 
         from bddjango import remove_temp_file
@@ -518,17 +529,24 @@ class ContentTypeAdmin(BaseAdmin):
         content = model_info.get('model_code')
         output_fname = model_info.get('model_name')
 
-        tempdir_rootpath = 'media/tempdir'  # 临时输出文件的根目录
+        tempdir_rootpath = os.path.join('media', 'tempdir')  # 临时输出文件的根目录
+
         output_dirpath = os.path.join(tempdir_rootpath, 'output')  # 临时输出文件的子目录
+        os.makedirs(output_dirpath, exist_ok=True)
+
+        # output_file_extension = ".txt"
+        output_file_extension = ".html"
         output_fpath = os.path.join(output_dirpath,
-                                    f'{output_fname}_{tt.get_current_beijing_time_str(tt.common_date_time_formats.ms_int)}.txt')
-        with open(output_fpath, 'w', encoding='utf-8') as f:
+                                    f'{output_fname}_{tt.get_current_beijing_time_str(tt.common_date_time_formats.ms_int)}{output_file_extension}')
+        output_encoding = 'gbk' if sys.platform == 'win32' else 'utf-8'
+        with open(output_fpath, 'w', encoding=output_encoding) as f:
             f.write(content)
 
         print('\n---------- auto_model:')
         print(content)
 
-        msg = f'成功生成模型代码, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_fpath}" target="_blank">点击此处查看</a>'
+        # msg = f'成功生成模型代码, 耗时: {tt.now(2)}秒. <br> <a href="/api/{output_fpath}" target="_blank">点击此处查看</a>'
+        msg = f'成功生成wiki, 耗时: {tt.now(2)}秒. <br> <a href="/api/file_upload/Doc/?output_filepath={output_fpath}" target="_blank">点击此处查看</a>'
         self.message_user(request, msg)
 
         from bddjango import remove_temp_file
@@ -567,6 +585,7 @@ def register_content_type_admin(ordering=None, app_filter=None, app_exclude=None
     """
     自动注册content_type_admin
 
+    :param ordering: 排序方式
     :param app_filter: app过滤列表
     :param app_exclude: app排除列表
     :param list_filter: 过滤字段
