@@ -77,7 +77,8 @@ class ListStatisticMixin:
             {
                 'name': 'shi_jian',
                 'ordering': '-shi_jian',
-                # 'pop_name_ls': ['1999']
+                # 'pop_name_ls': ['1999'],  # 删除一些值
+                # 'loc_ls': ['2005', '2001', '2020']  # 特定顺序返回
             }
         ]
     """
@@ -85,13 +86,14 @@ class ListStatisticMixin:
 
     get_statistic_dc = True             # 是否获取
     statistic_size = 10000              # 返回的个数, 由于统计结果通常不多, 默认返回全部比较好
-    statistic_descend = True            # 排序方式
+    statistic_descend = 1            # 排序方式
     pop_name_ls = [None, ""]            # 要删除的key_name
     only_get_statistic_dc = False       # 是否仅返回statistic_dc, 不反data等其它信息
 
-    statistic_actions = ['get_statistic_dc_func']  # 统计动作列表, 参考admin-actions设计, 但一般不用改动...有点多余...
     order_config_dc_ls = None           # 指定需要特制排序`ordering`或`pop_name_ls`的字段
 
+    statistic_actions = ['get_statistic_dc_func']  # 统计动作列表, 参考admin-actions设计, 但一般不用改动...有点多余...
+
     def get_list_ret(self, request, *args, **kwargs):
         ret, status, msg = super().get_list_ret(request, *args, **kwargs)
 
@@ -110,7 +112,8 @@ class ListStatisticMixin:
         only_get_statistic_dc = self.get_key_from_query_dc_or_self('only_get_statistic_dc', get_type='bool')
         if (get_statistic_dc or only_get_statistic_dc) and statistic_fields:
             statistic_size = self.get_key_from_query_dc_or_self('statistic_size')
-            statistic_descend = self.get_key_from_query_dc_or_self('statistic_descend', get_type='bool')
+            # statistic_descend = self.get_key_from_query_dc_or_self('statistic_descend', get_type='bool')
+            statistic_descend = self.get_key_from_query_dc_or_self('statistic_descend')
             order_config_dc_ls = self.order_config_dc_ls
 
             queryset = self.get_list_queryset()
