@@ -44,7 +44,6 @@ from django.db import models as m
 from django.db import connection
 from copy import deepcopy
 from .conf import db_engine
-# from rest_framework import serializers
 
 
 def get_list(query_dc, key):
@@ -827,11 +826,14 @@ def get_total_occurrence_times_by_keywords(total_qs_ls, search_field_ls, keyword
 
 
 
-def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, descend=True, order_config_dc_ls=None):
+def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, descend=1, order_config_dc_ls=None):
     """
     # 统计字段 fields 的值各出现了几次
     - statistic_fields 为迭代型时(如[name, id]), 只统计第一个字段, 然后将第二个字段用filter补上一个值
+    - descend: {0: `counts`顺序, 1:`counts`倒叙, 2: `self`顺序, 3: `self`倒叙}
     """
+    from bddjango import conv_queryset_to_dc_ls
+    from bddjango import conv_df_to_serializer_data
 
     assert isinstance(statistic_fields, list), 'statistic_fields必须为list类型!'
     statistic_size = int(statistic_size)
@@ -841,12 +843,22 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
     else:
         ordering = ['counts']
 
+    if descend == 0:
+        ordering = ['counts']
+    elif descend == 1:
+        ordering = ['-counts']
+    elif descend == 2:  # self顺序
+        ordering = descend
+    elif descend == 3:  # self倒序
+        ordering = descend
+
     order_df = None
     if order_config_dc_ls:
         _order_config_dc_i = {
             'name': None,
             'ordering': None,
-            'pop_name_ls': None
+            'pop_name_ls': None,
+            'loc_ls': None,
         }
         order_config_dc_ls.insert(0, _order_config_dc_i)
         order_df = pd.DataFrame(order_config_dc_ls)
@@ -865,26 +877,39 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
             field_qsv = queryset.values(field)
             dc_name = field
 
+        if not isinstance(ordering, list):
+            assert ordering in [2, 3], 'descend为2, 则按自身顺序排序, 为3则按自身倒序排序'
+            ordering = dc_name if ordering == 2 else f'-{dc_name}'
+
         if order_df is not None and dc_name in order_df.index:
             _ordering = order_df.loc[dc_name][0]
             _ordering = [_ordering] if isinstance(_ordering, str) else _ordering
-            _ordering = ordering if pd.isna(_ordering) else _ordering
+            _ordering = ordering if isinstance(_ordering, float) and pd.isna(_ordering) else _ordering
 
             pop_name_ls = order_df.loc[dc_name][1]
             pop_name_ls = [pop_name_ls] if isinstance(pop_name_ls, str) else pop_name_ls
-            pop_name_ls = None if pd.isna(pop_name_ls) else pop_name_ls
+            pop_name_ls = None if isinstance(pop_name_ls, float) and pd.isna(pop_name_ls) else pop_name_ls
+
+            loc_ls = order_df.loc[dc_name][2]
+            loc_ls = [loc_ls] if isinstance(loc_ls, str) else loc_ls
+            loc_ls = None if isinstance(loc_ls, float) and pd.isna(loc_ls) else loc_ls
 
             if pop_name_ls:
-                field_qsv = field_qsv.exclude(**{f'{dc_name}__in': pop_name_ls})
+                from bddjango import set_utils
+                _pop_name_ls = set_utils.get_ls_a_sub_b(pop_name_ls, loc_ls)
+                if _pop_name_ls:
+                    field_qsv = field_qsv.exclude(**{f'{dc_name}__in': _pop_name_ls})
             statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*_ordering)
+            if loc_ls:
+                dc_ls = conv_queryset_to_dc_ls(statistic_qsv)
+                df = pd.DataFrame(dc_ls)
+                df = df.set_index(dc_name)
+                df = df.loc[loc_ls]
+                df = df.reset_index()
+                statistic_qsv = conv_df_to_serializer_data(df)
         else:
             statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
 
-        # if order_by_self_descend_ls and dc_name in order_by_self_descend_ls:
-        #     # statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(f'-{dc_name}')
-        #     statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(_ordering)
-        # else:
-        #     statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
         dc_ls = list(statistic_qsv[:statistic_size])
 
         for dc in dc_ls:
